@@ -12,28 +12,39 @@ datadir = os.path.join(curdir, 'data')
 
 _H5PY_INSTALLED = True
 _HAS_YAML = True
-_HAS_TIMESERIES = True
+_HAS_XARRAY = _HAS_PANDAS = True
 
 try:
     import h5py
 except ImportError:
     _H5PY_INSTALLED = False
 
+import astropy.timeseries
+from astropy.timeseries import TimeSeries
+
 try:
-    import astropy.timeseries
-    from astropy.timeseries import TimeSeries
+    import xarray
+    from xarray import Dataset
 except ImportError:
-    _HAS_TIMESERIES = False
+    _HAS_XARRAY = False
+
+try:
+    import pandas
+    from pandas import DataFrame
+except ImportError:
+    _HAS_PANDAS = False
 
 try:
     import yaml
 except ImportError:
     _HAS_YAML = False
 
+
 class TestEvents(object):
 
     @classmethod
     def setup_class(self):
+        np.random.seed(57239875)
         self.time = [0.5, 1.5, 2.5, 3.5]
         self.counts = [3000, 2000, 2200, 3600]
         self.counts_flat = [3000, 3000, 3000, 3000]
@@ -103,13 +114,14 @@ class TestEvents(object):
         lc_sim = ev.to_lc(dt=lc.dt, tstart=lc.tstart, tseg=lc.tseg)
         assert np.all((lc - lc_sim).counts < 3 * np.sqrt(lc.counts))
 
-    def test_simulate_times_with_spline(self):
+    @pytest.mark.parametrize("use_spline", [True, False])
+    def test_simulate_times(self, use_spline):
         """Simulate photon arrival times, with use_spline option
         enabled.
         """
         lc = Lightcurve(self.time, self.counts_flat, gti=self.gti)
         ev = EventList()
-        ev.simulate_times(lc, use_spline=True)
+        ev.simulate_times(lc, use_spline=use_spline)
         lc_sim = ev.to_lc(dt=lc.dt, tstart=lc.tstart, tseg=lc.tseg)
         assert np.all((lc - lc_sim).counts < 3 * np.sqrt(lc.counts))
 
@@ -146,20 +158,17 @@ class TestEvents(object):
         fluxes = np.array(self.spectrum[1])
         ev = EventList(ncounts=1000)
         ev.simulate_energies(self.spectrum)
-        energy = [int(p) for p in ev.energy]
 
-        # Histogram energy to get shape approximation
-        gen_energy = ((np.array(energy) - 1) / 1).astype(int)
-        lc = np.bincount(energy)
-
-        # Remove first entry as it contains occurences of '0' element
-        lc = lc[1:len(lc)]
+        # Note: I'm passing the edges: when the bin center is 1, the
+        # edge is at 0.5
+        lc, _ = np.histogram(ev.energy, bins=np.arange(0.5, 7, 1))
 
         # Calculate probabilities and compare
         lc_prob = (lc/float(sum(lc)))
         fluxes_prob = fluxes/float(sum(fluxes))
 
         assert np.all(np.abs(lc_prob - fluxes_prob) < 3 * np.sqrt(fluxes_prob))
+        assert np.all((ev.energy >= 0.5)&(ev.energy < 6.5))
 
     def test_join_without_times_simulated(self):
         """Test if exception is raised when join method is
@@ -207,13 +216,20 @@ class TestEvents(object):
         assert np.allclose(ev_new.time, [1, 2, 3])
 
     def test_join_different_dt(self):
-        ev = EventList(time=[10, 20, 30], dt = 1)
-        ev_other = EventList(time=[40, 50, 60], dt = 3)
+        ev = EventList(time=[10, 20, 30], dt=1)
+        ev_other = EventList(time=[40, 50, 60], dt=3)
         with pytest.warns(UserWarning):
             ev_new = ev.join(ev_other)
 
         assert ev_new.dt == 3
 
+    def test_join_different_instr(self):
+        ev = EventList(time=[10, 20, 30], instr="fpma")
+        ev_other = EventList(time=[40, 50, 60], instr="fpmb")
+        ev_new = ev.join(ev_other)
+
+        assert ev_new.instr == "fpma,fpmb"
+
     def test_join_without_energy(self):
         ev = EventList(time=[1, 2, 3], energy=[3, 3, 3])
         ev_other = EventList(time=[4, 5])
@@ -254,9 +270,9 @@ class TestEvents(object):
         """Join two overlapping event lists.
         """
         ev = EventList(time=[1, 1, 2, 3, 4],
-                        energy=[3, 4, 7, 4, 3], gti=[[1, 2],[3, 4]])
+                       energy=[3, 4, 7, 4, 3], gti=[[1, 2], [3, 4]])
         ev_other = EventList(time=[5, 6, 6, 7, 10],
-                            energy=[4, 3, 8, 1, 2], gti=[[6, 7]])
+                             energy=[4, 3, 8, 1, 2], gti=[[6, 7]])
         with pytest.warns(UserWarning) as record:
             ev_new = ev.join(ev_other)
 
@@ -268,15 +284,15 @@ class TestEvents(object):
         assert (ev_new.energy ==
                 np.array([3, 4, 7, 4, 3, 4, 3, 8, 1, 2])).all()
         assert (ev_new.gti ==
-                np.array([[1, 2],[3, 4],[6, 7]])).all()
+                np.array([[1, 2], [3, 4], [6, 7]])).all()
 
     def test_overlapping_join(self):
         """Join two non-overlapping event lists.
         """
         ev = EventList(time=[1, 1, 10, 6, 5],
-                        energy=[10, 6, 3, 11, 2], gti=[[1, 3],[5, 6]])
+                       energy=[10, 6, 3, 11, 2], gti=[[1, 3], [5, 6]])
         ev_other = EventList(time=[5, 7, 6, 6, 10],
-                            energy=[2, 3, 8, 1, 2], gti=[[5, 7],[8, 10]])
+                             energy=[2, 3, 8, 1, 2], gti=[[5, 7], [8, 10]])
         ev_new = ev.join(ev_other)
 
         assert (ev_new.time ==
@@ -303,35 +319,44 @@ class TestEvents(object):
                 np.array([10, 6, 2, 2, 11, 8, 1, 3, 3, 2])).all()
         assert np.allclose(ev_new.gti, np.array([[5, 6]]))
 
-    @pytest.mark.skipif('not (_HAS_YAML and _HAS_TIMESERIES)')
+    @pytest.mark.skipif('not (_HAS_YAML)')
+    def test_io_warns(self):
+        ev = EventList(self.time)
+        with pytest.warns(DeprecationWarning):
+            ev.write('ascii_ev.ecsv', format_='pickle')
+
+        with pytest.warns(DeprecationWarning):
+            ev = ev.read('ascii_ev.ecsv', format_='pickle')
+
+    @pytest.mark.skipif('not (_HAS_YAML)')
     def test_io_with_ascii(self):
         ev = EventList(self.time)
-        ev.write('ascii_ev.ecsv', format_='ascii')
-        ev = ev.read('ascii_ev.ecsv', format_='ascii')
+        ev.write('ascii_ev.ecsv', fmt='ascii')
+        ev = ev.read('ascii_ev.ecsv', fmt='ascii')
         print(ev.time, self.time)
         assert np.allclose(ev.time, self.time)
         os.remove('ascii_ev.ecsv')
 
     def test_io_with_pickle(self):
         ev = EventList(self.time, mjdref=54000)
-        ev.write('ev.pickle', format_='pickle')
-        ev = ev.read('ev.pickle', format_='pickle')
+        ev.write('ev.pickle', fmt='pickle')
+        ev = ev.read('ev.pickle', fmt='pickle')
         assert np.allclose(ev.time, self.time)
         os.remove('ev.pickle')
 
     @pytest.mark.skipif("not _H5PY_INSTALLED")
     def test_io_with_hdf5(self):
         ev = EventList(time=self.time, mjdref=54000)
-        ev.write('ev.hdf5', format_='hdf5')
+        ev.write('ev.hdf5', fmt='hdf5')
 
-        ev = ev.read('ev.hdf5', format_='hdf5')
+        ev = ev.read('ev.hdf5', fmt='hdf5')
         assert np.allclose(ev.time, self.time)
         os.remove('ev.hdf5')
 
     def test_io_with_fits(self):
         ev = EventList(time=self.time, mjdref=54000)
-        ev.write('ev.fits', format_='fits')
-        ev = ev.read('ev.fits', format_='fits')
+        ev.write('ev.fits', fmt='fits')
+        ev = ev.read('ev.fits', fmt='fits')
         assert np.allclose(ev.time, self.time)
         os.remove('ev.fits')
 
@@ -341,7 +366,7 @@ class TestEvents(object):
         """
         fname = os.path.join(datadir, 'monol_testA.evt')
         ev = EventList()
-        ev = ev.read(fname, format_='hea')
+        ev = ev.read(fname, fmt='hea')
         assert np.isclose(ev.mjdref, 55197.00076601852)
 
     def test_fits_with_additional(self):
@@ -350,14 +375,16 @@ class TestEvents(object):
         """
         fname = os.path.join(datadir, 'xmm_test.fits')
         ev = EventList()
-        ev = ev.read(fname, format_='hea', additional_columns=['PRIOR'])
+        ev = ev.read(fname, fmt='hea', additional_columns=['PRIOR'])
         assert hasattr(ev, 'prior')
 
-    @pytest.mark.skipif('not _HAS_TIMESERIES')
+    def test_timeseries_empty_evts(self):
+        N = len(self.time)
+        ev = EventList()
+        ts = ev.to_astropy_timeseries()
+        assert len(ts.columns) == 0
+
     def test_timeseries_roundtrip(self):
-        """Test that io methods raise Key Error when
-        wrong format is provided.
-        """
         N = len(self.time)
         ev = EventList(time=self.time, gti=self.gti, energy=np.zeros(N),
                        pi=np.ones(N), mission="BUBU", instr="BABA",
@@ -370,9 +397,6 @@ class TestEvents(object):
             assert getattr(ev, attr) == getattr(new_ev, attr)
 
     def test_table_roundtrip(self):
-        """Test that io methods raise Key Error when
-        wrong format is provided.
-        """
         N = len(self.time)
         ev = EventList(time=self.time, gti=self.gti, energy=np.zeros(N),
                        pi=np.ones(N), mission="BUBU", instr="BABA",
@@ -384,3 +408,28 @@ class TestEvents(object):
         for attr in ['mission', 'instr', 'mjdref']:
             assert getattr(ev, attr) == getattr(new_ev, attr)
 
+    @pytest.mark.skipif('not _HAS_XARRAY')
+    def test_xarray_roundtrip(self):
+        N = len(self.time)
+        ev = EventList(time=self.time, gti=self.gti, energy=np.zeros(N),
+                       pi=np.ones(N), mission="BUBU", instr="BABA",
+                       mjdref=53467.)
+        ts = ev.to_xarray()
+        new_ev = ev.from_xarray(ts)
+        for attr in ['time', 'energy', 'pi', 'gti']:
+            assert np.allclose(getattr(ev, attr), getattr(new_ev, attr))
+        for attr in ['mission', 'instr', 'mjdref']:
+            assert getattr(ev, attr) == getattr(new_ev, attr)
+
+    @pytest.mark.skipif('not _HAS_PANDAS')
+    def test_pandas_roundtrip(self):
+        N = len(self.time)
+        ev = EventList(time=self.time, gti=self.gti, energy=np.zeros(N),
+                       pi=np.ones(N), mission="BUBU", instr="BABA",
+                       mjdref=53467.)
+        ts = ev.to_pandas()
+        new_ev = ev.from_pandas(ts)
+        for attr in ['time', 'energy', 'pi', 'gti']:
+            assert np.allclose(getattr(ev, attr), getattr(new_ev, attr))
+        for attr in ['mission', 'instr', 'mjdref']:
+            assert getattr(ev, attr) == getattr(new_ev, attr)
