@@ -3,9 +3,9 @@ import pytest
 import stingray.spectroscopy as spec
 from stingray.filters import Window1D
 from stingray import Lightcurve, AveragedPowerspectrum, AveragedCrossspectrum, Powerspectrum, Crossspectrum
+from stingray.utils import fft
 from stingray.modeling import fit_lorentzians, fit_crossspectrum, fit_powerspectrum
 from stingray.filters import Optimal1D, Window1D
-from scipy.fft import fft
 from astropy.modeling import models
 from astropy.table import Table, Column
 
